AddressDetailsData class

Constructors

AddressDetailsData({String? masterUserAddressID, String? type, String? landmark, String? address, String? city, String? cityId, String? state, String? stateId, String? pincode, String? country, String? countryId, String? documentType, String? documentNumber, String? documentFront, String? documentBack, String? panNumber, String? panCardFront})
AddressDetailsData.fromJson(dynamic json)

Properties

address → String?
no setter
city → String?
no setter
cityId → String?
no setter
country → String?
no setter
countryId → String?
no setter
documentBack → String?
no setter
documentFront → String?
no setter
documentNumber → String?
no setter
documentType → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
landmark → String?
no setter
masterUserAddressID → String?
no setter
panCardFront → String?
no setter
panNumber → String?
no setter
pincode → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String?
no setter
stateId → String?
no setter
type → String?
no setter

Methods

copyWith({String? masterUserAddressID, String? type, String? landmark, String? address, String? city, String? cityId, String? state, String? stateId, String? pincode, String? country, String? countryId, String? documentType, String? documentNumber, String? documentFront, String? documentBack, String? panNumber, String? panCardFront}) → AddressDetailsData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited