AdvanceInfoData class

Constructors

AdvanceInfoData({String? type, String? reraNumber, String? cPUserId, String? companyName, String? gSTRegistered, String? panNumber, String? reraCertificate, String? passportSizePhoto, String? panCardFront})
AdvanceInfoData.fromJson(dynamic json)

Properties

companyName String?
no setter
cPUserId String?
no setter
gSTRegistered String?
no setter
hashCode int
The hash code for this object.
no setterinherited
panCardFront String?
no setter
panNumber String?
no setter
passportSizePhoto String?
no setter
reraCertificate String?
no setter
reraNumber String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setter

Methods

copyWith({String? type, String? reraNumber, String? cPUserId, String? companyName, String? gSTRegistered, String? panNumber, String? reraCertificate, String? passportSizePhoto, String? panCardFront}) AdvanceInfoData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited