DataList class

Constructors

DataList({List<AllInquiries>? allInquiries})
DataList.fromJson(dynamic json)

Properties

allInquiries ↔ List<AllInquiries>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageIndexNotifier ↔ ValueNotifier<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<AllInquiries>? allInquiries}) → DataList
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited