FollowUpHistory class

Constructors

FollowUpHistory({String? id, String? inquiryId, String? userId, String? projectId, String? projectTitle, String? pageName, AddFollowUp? addFollowUp, SalesData? salesData, TransferFrom? transferFrom, TransferTo? transferTo, TransferFromAdmin? transferFromAdmin, TransferFromProject? transferFromProject, TransferToProject? transferToProject, String? transferTime, String? unitNo, String? lostReason, String? activity, String? task, String? remarks, String? createdAt, String? createdAtTime, String? followUpDate, String? followUpDateSort, String? followUpDateTime, String? followUpDate2})
FollowUpHistory.fromJson(dynamic json)

Properties

activity String?
no setter
addFollowUp AddFollowUp?
no setter
createdAt String?
getter/setter pair
createdAtTime String?
no setter
followUpDate String?
getter/setter pair
followUpDate2 String?
getter/setter pair
followUpDateSort String?
getter/setter pair
followUpDateTime String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
inquiryId String?
no setter
lostReason String?
no setter
pageName String?
no setter
projectId String?
no setter
projectTitle String?
no setter
remarks String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesData SalesData?
no setter
task String?
getter/setter pair
transferFrom TransferFrom?
no setter
transferFromAdmin TransferFromAdmin?
no setter
transferFromProject TransferFromProject?
no setter
transferTime String?
no setter
transferTo TransferTo?
no setter
transferToProject TransferToProject?
no setter
unitNo String?
no setter
userId String?
no setter

Methods

copyWith({String? id, String? inquiryId, String? userId, String? projectId, String? projectTitle, String? pageName, AddFollowUp? addFollowUp, SalesData? salesData, TransferFrom? transferFrom, TransferTo? transferTo, TransferFromAdmin? transferFromAdmin, TransferFromProject? transferFromProject, TransferToProject? transferToProject, String? transferTime, String? unitNo, String? lostReason, String? activity, String? task, String? remarks, String? createdAt, String? createdAtTime, String? followUpDate, String? followUpDateSort, String? followUpDateTime, String? followUpDate2}) FollowUpHistory
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited