LeadRights class
Constructors
- LeadRights({num? transfer, num? addFollowUp, num? edit})
- LeadRights.fromJson(dynamic json)
Properties
- addFollowUp → num?
-
no setter
- edit → num?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transfer → num?
-
no setter
Methods
-
copyWith(
{num? transfer, num? addFollowUp, num? edit}) → LeadRights -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited