LeadTab class

Constructors

LeadTab({String? type3, String? title, String? title2, num? total, num? showTotal})
LeadTab.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTotal num?
no setter
title String?
no setter
title2 String?
no setter
total num?
no setter
type3 String?
no setter

Methods

copyWith({String? type3, String? title, String? title2, num? total, num? showTotal}) LeadTab
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited