LeadTotal class

Constructors

LeadTotal({String? newLeadTotal, String? followUpsTotal, String? reInquiryTotal, String? dueTotal})
LeadTotal.fromJson(dynamic json)

Properties

dueTotal String?
no setter
followUpsTotal String?
no setter
hashCode int
The hash code for this object.
no setterinherited
newLeadTotal String?
no setter
reInquiryTotal String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? newLeadTotal, String? followUpsTotal, String? reInquiryTotal, String? dueTotal}) LeadTotal
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited