FollowDate class

Constructors

FollowDate({String? format, String? time, String? sort})
FollowDate.fromJson(dynamic json)

Properties

format String?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort String?
no setter
time String?
no setter

Methods

copyWith({String? format, String? time, String? sort}) FollowDate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited