FollowUpHistory class

Constructors

FollowUpHistory({String? id, String? inquiryId, String? userId, String? projectId, String? projectTitle, String? pageName, AddFollowUp? addFollowUp, SalesData? salesData, TransferSales? transferSales, num? transferFromAdmin, TransferInquiry? transferInquiry, String? transferTime, String? unitNo, String? lostReason, String? activity, String? task, String? remarks, num? followUpAdd, String? createdAt, String? createdAtTime, String? followUpDate2, String? followUpDate, String? followUpDateSort, String? followUpDateTime, String? followUpDateNew})
FollowUpHistory.fromJson(dynamic json)

Properties

activity String?
no setter
addFollowUp AddFollowUp?
no setter
createdAt String?
no setter
createdAtTime String?
no setter
followUpAdd num?
no setter
followUpDate String?
no setter
followUpDate2 String?
no setter
followUpDateNew String?
no setter
followUpDateSort String?
no setter
followUpDateTime String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
inquiryId String?
no setter
lostReason String?
no setter
pageName String?
no setter
projectId String?
no setter
projectTitle String?
no setter
remarks String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesData SalesData?
no setter
task String?
no setter
transferFromAdmin num?
no setter
transferInquiry TransferInquiry?
no setter
transferSales TransferSales?
no setter
transferTime String?
no setter
unitNo String?
no setter
userId String?
no setter

Methods

copyWith({String? id, String? inquiryId, String? userId, String? projectId, String? projectTitle, String? pageName, AddFollowUp? addFollowUp, SalesData? salesData, TransferSales? transferSales, num? transferFromAdmin, TransferInquiry? transferInquiry, String? transferTime, String? unitNo, String? lostReason, String? activity, String? task, String? remarks, num? followUpAdd, String? createdAt, String? createdAtTime, String? followUpDate2, String? followUpDate, String? followUpDateSort, String? followUpDateTime, String? followUpDateNew}) FollowUpHistory
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited