menu
reecosys_app package
documentation
model/AllInquiryResponse.dart
StageTab class
StageTab class
dark_mode
light_mode
StageTab
class
Constructors
StageTab
({
String
?
task
,
num
?
total
})
StageTab.fromJson
(
dynamic
json
)
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
task
→
String
?
no setter
total
→
num
?
no setter
Methods
copyWith
(
{
String
?
task
,
num
?
total
})
→
StageTab
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
reecosys_app package
documentation
model/AllInquiryResponse
StageTab class
AllInquiryResponse library