RelationshipManagerData class

Constructors

RelationshipManagerData({String? masterUserId, String? name, String? email, String? contactNo, String? type})
RelationshipManagerData.fromJson(dynamic json)

Properties

contactNo → String?
no setter
email → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
masterUserId → String?
no setter
name → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
no setter

Methods

copyWith({String? masterUserId, String? name, String? email, String? contactNo, String? type}) → RelationshipManagerData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited