Data class

Constructors

Data({String? id, String? flatType, String? category, bool isSelected = false, bool isLoading = false})
Data.fromJson(dynamic json)

Properties

category → String?
no setter
flatType → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setter
isLoading ↔ bool
getter/setter pair
isSelected ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? flatType, String? category, bool isSelected = false, bool isLoading = false}) → Data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited