CampaignResponseModel class

Constructors

CampaignResponseModel({List<CampaignDataItem>? data, num? success, num? totalRecords, String? message})
CampaignResponseModel.fromJson(dynamic json)

Properties

data → List<CampaignDataItem>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → num?
no setter
totalRecords → num?
no setter

Methods

copyWith({List<CampaignDataItem>? data, num? success, num? totalRecords, String? message}) → CampaignResponseModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited