CompanyList class
Constructors
- CompanyList({num? id, num? masterUserId, String? name, String? isApproved, num? createdAtToday, String? createdAt, String? createdTime})
- CompanyList.fromJson(dynamic json)
Properties
- createdAt → String?
-
no setter
- createdAtToday → num?
-
no setter
- createdTime → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → num?
-
no setter
- isApproved → String?
-
no setter
- masterUserId → num?
-
no setter
- name → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{num? id, num? masterUserId, String? name, String? isApproved, num? createdAtToday, String? createdAt, String? createdTime}) → CompanyList -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited