CountryData class

Constructors

CountryData({String? id, String? iso, String? flag, String? name, String? nicename, String? iso3, String? numcode, String? phonecode, String? sort})
CountryData.fromJson(dynamic json)

Properties

flag String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
iso String?
no setter
iso3 String?
no setter
name String?
no setter
nicename String?
no setter
numcode String?
no setter
phonecode String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort String?
no setter

Methods

copyWith({String? id, String? iso, String? flag, String? name, String? nicename, String? iso3, String? numcode, String? phonecode, String? sort}) CountryData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited