CpTotal class

Constructors

CpTotal({num? verified, num? todayBirthdate, num? company})
CpTotal.fromJson(dynamic json)

Properties

company num?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
todayBirthdate num?
no setter
verified num?
no setter

Methods

copyWith({num? verified, num? todayBirthdate, num? company}) CpTotal
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited