CpMemberDataResponse class

Constructors

CpMemberDataResponse({String? type, String? description, bool isSelected = false, String? image})
CpMemberDataResponse.fromJson(dynamic json)

Properties

description String?
no setter
hashCode int
The hash code for this object.
no setterinherited
image String?
no setter
isSelected bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setter

Methods

copyWith({String? type, String? description, String? image, bool isSelected = false}) CpMemberDataResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited