Document class

Constructors

Document({String? usersDocumentID, String? type, String? masterUserId, String? documentNumber, String? documentTypeID, String? documentType, String? documentPhotoFront, String? documentPhotoFrontFull, String? documentPhotoFrontName, String? documentPhotoBack, String? documentPhotoBackFull, String? documentPhotoBackName})
Document.fromJson(dynamic json)

Properties

documentNumber → String?
no setter
documentPhotoBack → String?
no setter
documentPhotoBackFull → String?
no setter
documentPhotoBackName → String?
no setter
documentPhotoFront → String?
no setter
documentPhotoFrontFull → String?
no setter
documentPhotoFrontName → String?
no setter
documentType → String?
no setter
documentTypeID → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
masterUserId → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
no setter
usersDocumentID → String?
no setter

Methods

copyWith({String? usersDocumentID, String? type, String? masterUserId, String? documentNumber, String? documentTypeID, String? documentType, String? documentPhotoFront, String? documentPhotoFrontFull, String? documentPhotoFrontName, String? documentPhotoBack, String? documentPhotoBackFull, String? documentPhotoBackName}) → Document
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited