DocumentTypeData class

Constructors

DocumentTypeData({String? documentTypeID, String? documentType, Document? document})
DocumentTypeData.fromJson(dynamic json)

Properties

document Document?
no setter
documentType String?
no setter
documentTypeID String?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? documentTypeID, String? documentType, Document? document}) DocumentTypeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited