FeedData class

Constructors

FeedData({String? id, String? title, String? description, String? type, String? publishedDate, String? publishedDateFormat, String? publishedDateFormatTime, String? media, String? image, String? thumbImage, String? isActive, String? masterUserId, String? createdAt, String? createdTime, String? updatedAt, String? updatedTime})
FeedData.fromJson(dynamic json)

Properties

createdAt → String?
no setter
createdTime → String?
no setter
description → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setter
image → String?
no setter
isActive → String?
no setter
masterUserId → String?
no setter
media → String?
no setter
publishedDate → String?
no setter
publishedDateFormat → String?
no setter
publishedDateFormatTime → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbImage → String?
no setter
title → String?
no setter
type → String?
no setter
updatedAt → String?
no setter
updatedTime → String?
no setter

Methods

copyWith({String? id, String? title, String? description, String? type, String? publishedDate, String? publishedDateFormat, String? publishedDateFormatTime, String? media, String? image, String? thumbImage, String? isActive, String? masterUserId, String? createdAt, String? createdTime, String? updatedAt, String? updatedTime}) → FeedData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited