CampaignDate class

Constructors

CampaignDate({String? fromDate, String? fromDateTime, String? toDate, String? toDateTime})
CampaignDate.fromJson(dynamic json)

Properties

fromDate String?
no setter
fromDateTime String?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate String?
no setter
toDateTime String?
no setter

Methods

copyWith({String? fromDate, String? fromDateTime, String? toDate, String? toDateTime}) CampaignDate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited