FeedDate class
Constructors
- FeedDate({String? publishedDate, String? publishedDateFormat, String? publishedDateFormatTime})
- FeedDate.fromJson(dynamic json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- publishedDate → String?
-
no setter
- publishedDateFormat → String?
-
no setter
- publishedDateFormatTime → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? publishedDate, String? publishedDateFormat, String? publishedDateFormatTime}) → FeedDate -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited