FeedMedia class

Constructors

FeedMedia({String? type, String? media, String? thumbImage})
FeedMedia.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
media String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbImage String?
no setter
type String?
no setter

Methods

copyWith({String? type, String? media, String? thumbImage}) FeedMedia
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited