FollowUpHistoryResponse class

Constructors

FollowUpHistoryResponse({InquiryData? inquiryData, List<FollowUpHistoryData>? data, String? message, String? inquiryId, num? success})
FollowUpHistoryResponse.fromJson(dynamic json)

Properties

data List<FollowUpHistoryData>?
no setter
hashCode int
The hash code for this object.
no setterinherited
inquiryData InquiryData?
no setter
inquiryId String?
no setter
message String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success num?
no setter

Methods

copyWith({InquiryData? inquiryData, List<FollowUpHistoryData>? data, String? message, String? inquiryId, num? success}) FollowUpHistoryResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited