InquiresType class

Constructors

InquiresType({String? type, String? typeShow, bool isSelected = false, String? adminModuleId})
InquiresType.fromJson(dynamic json)

Properties

adminModuleId String?
no setter
hashCode int
The hash code for this object.
no setterinherited
isSelected bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setter
typeShow String?
no setter

Methods

copyWith({String? type, String? typeShow, String? adminModuleId, bool isSelected = false}) InquiresType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited