menu
reecosys_app package
documentation
model/InquiryDetailsResponse.dart
CpData class
CpData class
dark_mode
light_mode
CpData
class
Constructors
CpData
({
String
?
userId
,
String
?
firstName
,
String
?
lastName
})
CpData.fromJson
(
dynamic
json
)
Properties
firstName
→
String
?
no setter
hashCode
→
int
The hash code for this object.
no setter
inherited
lastName
→
String
?
no setter
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
userId
→
String
?
no setter
Methods
copyWith
(
{
String
?
userId
,
String
?
firstName
,
String
?
lastName
})
→
CpData
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
reecosys_app package
documentation
model/InquiryDetailsResponse
CpData class
InquiryDetailsResponse library