menu
reecosys_app package
documentation
model/InquiryDropDownResponse.dart
Category class
Category class
dark_mode
light_mode
Category
class
Constructors
Category
({
String
?
id
,
String
?
name
})
Category.fromJson
(
dynamic
json
)
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
id
→
String
?
no setter
name
→
String
?
no setter
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
copyWith
(
{
String
?
id
,
String
?
name
})
→
Category
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
reecosys_app package
documentation
model/InquiryDropDownResponse
Category class
InquiryDropDownResponse library