Data class

Constructors

Data({List<Source>? source, List<SubSource>? subSource, List<Budget>? budget, List<Priority>? priority, List<Area>? area, List<Category>? category, List<LeadType>? leadType, List<UnitType>? unitType, List<UnitType>? buyType})
Data.fromJson(dynamic json)

Properties

area → List<Area>?
no setter
budget → List<Budget>?
no setter
buyType → List<UnitType>?
no setter
category → List<Category>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
leadType → List<LeadType>?
no setter
priority → List<Priority>?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → List<Source>?
no setter
subSource → List<SubSource>?
no setter
unitType → List<UnitType>?
no setter

Methods

copyWith({List<Source>? source, List<SubSource>? subSource, List<Budget>? budget, List<Priority>? priority, List<Area>? area, List<Category>? category, List<LeadType>? leadType, List<UnitType>? unitType, List<UnitType>? buyType}) → Data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited