menu
reecosys_app package
documentation
model/InquiryDropDownResponse.dart
LeadType class
LeadType class
dark_mode
light_mode
LeadType
class
Constructors
LeadType
({
String
?
id
,
String
?
name
})
LeadType.fromJson
(
dynamic
json
)
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
id
→
String
?
no setter
name
→
String
?
no setter
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
copyWith
(
{
String
?
id
,
String
?
name
})
→
LeadType
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
reecosys_app package
documentation
model/InquiryDropDownResponse
LeadType class
InquiryDropDownResponse library