SubSource class

Constructors

SubSource({String? id, String? projectSourceId, bool isSelected = false, String? name})
SubSource.fromJson(dynamic json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setter
isSelected ↔ bool
getter/setter pair
name → String?
no setter
projectSourceId → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? projectSourceId, String? name, bool isSelected = false}) → SubSource
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited