InquiryDetails class

Constructors

InquiryDetails({String? userId, String? clientName, String? clientContactNo, String? cpFirstName, String? cpLastName, String? cpContactNo, String? emailAddress, String? projectTitle, String? pageName, String? remarks, String? address, String? leadSource, String? leadSubSource, String? leadBudget, String? leadPriority, String? leadArea, String? leadCategory, String? leadType, String? leadUnitType, num? feedbackFound})
InquiryDetails.fromJson(dynamic json)

Properties

address String?
no setter
clientContactNo String?
no setter
clientName String?
no setter
cpContactNo String?
no setter
cpFirstName String?
no setter
cpLastName String?
no setter
emailAddress String?
no setter
feedbackFound num?
no setter
hashCode int
The hash code for this object.
no setterinherited
leadArea String?
no setter
leadBudget String?
no setter
leadCategory String?
no setter
leadPriority String?
no setter
leadSource String?
no setter
leadSubSource String?
no setter
leadType String?
no setter
leadUnitType String?
no setter
pageName String?
no setter
projectTitle String?
no setter
remarks String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
no setter

Methods

copyWith({String? userId, String? clientName, String? clientContactNo, String? cpFirstName, String? cpLastName, String? cpContactNo, String? emailAddress, String? projectTitle, String? pageName, String? remarks, String? address, String? leadSource, String? leadSubSource, String? leadBudget, String? leadPriority, String? leadArea, String? leadCategory, String? leadType, String? leadUnitType, num? feedbackFound}) InquiryDetails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited