InquiryFollowUpResponseModel class

Constructors

InquiryFollowUpResponseModel({InquiryDetails? inquiryDetails, List<FollowUpHistory>? followUpHistory, List<InquiryHistory>? inquiryHistory, String? message, String? inquiryId, num? totalInquiries, num? success})
InquiryFollowUpResponseModel.fromJson(dynamic json)

Properties

followUpHistory → List<FollowUpHistory>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
inquiryDetails → InquiryDetails?
no setter
inquiryHistory → List<InquiryHistory>?
no setter
inquiryId → String?
no setter
message → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → num?
no setter
totalInquiries → num?
no setter

Methods

copyWith({InquiryDetails? inquiryDetails, List<FollowUpHistory>? followUpHistory, List<InquiryHistory>? inquiryHistory, String? message, String? inquiryId, num? totalInquiries, num? success}) → InquiryFollowUpResponseModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited