InquiryHistory class

Constructors

InquiryHistory({String? id, String? inquiryId, String? type, String? projectTitle, String? pageName, String? userId, String? salesName, String? clientFirstName, String? clientLastName, String? emailAddress, String? leadSource, String? leadSubSource, String? ivrsCallPath, String? masterUserIdIvrsCall, String? ivrsName, String? dateTime, String? dateFormat, bool isSelected = false})
InquiryHistory.fromJson(dynamic json)

Properties

clientFirstName String?
no setter
clientLastName String?
no setter
dateFormat String?
no setter
dateTime String?
no setter
emailAddress String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
inquiryId String?
no setter
isSelected bool
getter/setter pair
ivrsCallPath String?
no setter
ivrsName String?
no setter
leadSource String?
no setter
leadSubSource String?
no setter
masterUserIdIvrsCall String?
no setter
pageName String?
no setter
projectTitle String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesName String?
no setter
type String?
no setter
userId String?
no setter

Methods

copyWith({String? id, String? inquiryId, String? type, String? projectTitle, String? pageName, String? userId, String? salesName, String? clientFirstName, String? clientLastName, String? emailAddress, String? leadSource, String? leadSubSource, String? ivrsCallPath, String? masterUserIdIvrsCall, String? ivrsName, String? dateTime, String? dateFormat, bool isSelected = false}) InquiryHistory
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited