InquiryHistoryData class

Constructors

InquiryHistoryData({String? id, String? inquiryId, String? type, String? projectId, String? projectTitle, String? userId, String? dateFormat, String? salesName, String? clientFirstName, String? clientLastName, String? clientContactNo, String? emailAddress, String? leadSource, String? leadSubSource, String? ivrsCallPath, String? masterUserIdIvrsCall, String? ivrsName, num? createdAtToday, String? createdAt, String? createdTime})
InquiryHistoryData.fromJson(dynamic json)

Properties

clientContactNo String?
no setter
clientFirstName String?
no setter
clientLastName String?
no setter
createdAt String?
no setter
createdAtToday num?
no setter
createdTime String?
no setter
dateFormat String?
no setter
emailAddress String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
inquiryId String?
no setter
ivrsCallPath String?
no setter
ivrsName String?
no setter
leadSource String?
no setter
leadSubSource String?
no setter
masterUserIdIvrsCall String?
no setter
projectId String?
no setter
projectTitle String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesName String?
no setter
type String?
no setter
userId String?
no setter

Methods

copyWith({String? id, String? inquiryId, String? type, String? projectId, String? projectTitle, String? userId, String? dateFormat, String? salesName, String? clientFirstName, String? clientLastName, String? clientContactNo, String? emailAddress, String? leadSource, String? leadSubSource, String? ivrsCallPath, String? masterUserIdIvrsCall, String? ivrsName, num? createdAtToday, String? createdAt, String? createdTime}) InquiryHistoryData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited