DataItem class
Constructors
-
DataItem({List<
InvestType> ? investType, List<InvestTime> ? investTime}) - DataItem.fromJson(dynamic json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
investTime
→ List<
InvestTime> ? -
no setter
-
investType
→ List<
InvestType> ? -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< InvestType> ? investType, List<InvestTime> ? investTime}) → DataItem -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited