InvestType class

Constructors

InvestType({String? id, String? type, String? name, String? customDate, String? createdAt, String? isActive, String? isDeleted, String? sort, String? icon, String? masterUserId})
InvestType.fromJson(dynamic json)

Properties

createdAt String?
no setter
customDate String?
no setter
hashCode int
The hash code for this object.
no setterinherited
icon String?
no setter
id String?
no setter
isActive String?
no setter
isDeleted String?
no setter
masterUserId String?
no setter
name String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort String?
no setter
type String?
no setter

Methods

copyWith({String? id, String? type, String? name, String? customDate, String? createdAt, String? isActive, String? isDeleted, String? sort, String? icon, String? masterUserId}) InvestType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited