Data class

Constructors

Data({String? masterUserId, String? contactNo, String? userId, String? loginType, num? cpNew})
Data.fromJson(dynamic json)

Properties

contactNo → String?
no setter
cpNew → num?
no setter
hashCode → int
The hash code for this object.
no setterinherited
loginType → String?
no setter
masterUserId → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String?
no setter

Methods

copyWith({String? masterUserId, String? contactNo, String? userId, String? loginType, num? cpNew}) → Data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited