ProjectInquiry class

Constructors

ProjectInquiry({bool? manageMasterAdmin, bool? activation, num? adminModuleId})
ProjectInquiry.fromJson(dynamic json)

Properties

activation → bool?
no setter
adminModuleId → num?
no setter
hashCode → int
The hash code for this object.
no setterinherited
manageMasterAdmin → bool?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? manageMasterAdmin, bool? activation, num? adminModuleId}) → ProjectInquiry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited