QuarterDetails class

Constructors

QuarterDetails({String? parentId, String? name, String? fromTime, String? toTime, String? quarterId, String? masterUserId})
QuarterDetails.fromJson(dynamic json)

Properties

fromTime String?
no setter
hashCode int
The hash code for this object.
no setterinherited
masterUserId String?
no setter
name String?
no setter
parentId String?
no setter
quarterId String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toTime String?
no setter

Methods

copyWith({String? parentId, String? name, String? fromTime, String? toTime, String? quarterId, String? masterUserId}) QuarterDetails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited