TeamsTarget class

Constructors

TeamsTarget({String? name, String? type, String? userId, String? unit, String? target})
TeamsTarget.fromJson(dynamic json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String?
no setter
type → String?
no setter
unit → String?
no setter
userId → String?
no setter

Methods

copyWith({String? name, String? type, String? userId, String? unit, String? target}) → TeamsTarget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited