NomineeData class

Constructors

NomineeData({String? usersNomineeID, String? masterUserId, String? type, String? fullName, String? contactNumber, String? email, String? relation, String? landmark, String? address, String? city, String? cityId, String? state, String? stateId, String? pincode, String? country, String? countryId, String? dob, String? identityDocument, String? identityDocumentFull})
NomineeData.fromJson(dynamic json)

Properties

address String?
no setter
city String?
no setter
cityId String?
no setter
contactNumber String?
no setter
country String?
no setter
countryId String?
no setter
dob String?
no setter
email String?
no setter
fullName String?
no setter
hashCode int
The hash code for this object.
no setterinherited
identityDocument String?
no setter
identityDocumentFull String?
no setter
landmark String?
no setter
masterUserId String?
no setter
pincode String?
no setter
relation String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
no setter
stateId String?
no setter
type String?
no setter
usersNomineeID String?
no setter

Methods

copyWith({String? usersNomineeID, String? masterUserId, String? type, String? fullName, String? contactNumber, String? email, String? relation, String? landmark, String? address, String? city, String? cityId, String? state, String? stateId, String? pincode, String? country, String? countryId, String? dob, String? identityDocument, String? identityDocumentFull}) NomineeData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited