NomineeListResponseModel class

Constructors

NomineeListResponseModel({List<NomineeData>? nomineeData, num? success, String? message})
NomineeListResponseModel.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
no setter
nomineeData List<NomineeData>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success num?
no setter

Methods

copyWith({List<NomineeData>? nomineeData, num? success, String? message}) NomineeListResponseModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited