DataProfile class

Constructors

DataProfile({String? masterUserId, String? groupId, String? name, String? userName, String? email, String? contactNo, String? birthdate, String? isActive, String? accountName, String? type, String? profileImage, String? logoGet, String? profileImageGet, String? subscriptionPlan, String? gender, String? companyName})
DataProfile.fromJson(dynamic json)

Properties

accountName String?
no setter
birthdate String?
no setter
companyName String?
no setter
contactNo String?
no setter
email String?
no setter
gender String?
no setter
groupId String?
no setter
hashCode int
The hash code for this object.
no setterinherited
isActive String?
no setter
no setter
logoGet String?
no setter
masterUserId String?
no setter
name String?
no setter
profileImage String?
no setter
profileImageGet String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionPlan String?
no setter
type String?
no setter
userName String?
no setter

Methods

copyWith({String? masterUserId, String? groupId, String? name, String? userName, String? email, String? contactNo, String? birthdate, String? isActive, String? accountName, String? type, String? profileImage, String? logoGet, String? profileImageGet, String? subscriptionPlan, String? gender, String? companyName}) DataProfile
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited