Data class
Constructors
- Data({UserData? userData, MemberData? memberData})
- Data.fromJson(dynamic json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- memberData → MemberData?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userData → UserData?
-
no setter
Methods
-
copyWith(
{UserData? userData, MemberData? memberData}) → Data -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited