MemberData class

Constructors

MemberData({num? propertySold, String? memberType, num? propertyToBeSold, String? beacmeMemberType})
MemberData.fromJson(dynamic json)

Properties

beacmeMemberType String?
no setter
hashCode int
The hash code for this object.
no setterinherited
memberType String?
no setter
propertySold num?
no setter
propertyToBeSold num?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({num? propertySold, String? memberType, num? propertyToBeSold, String? beacmeMemberType}) MemberData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited