AmenitiesImages class

Constructors

AmenitiesImages({num? id, String? projectId, String? image, String? imageName})
AmenitiesImages.fromJson(dynamic json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → num?
no setter
image → String?
no setter
imageName → String?
no setter
projectId → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({num? id, String? projectId, String? image, String? imageName}) → AmenitiesImages
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited