DocumentOtherData class
Constructors
Properties
- createdAt → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
no setter
- iconFull → String?
-
no setter
- isSelected ↔ bool
-
getter/setter pair
- projectDocumentId → num?
-
no setter
- projectId → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
no setter
- url → String?
-
no setter
- urlName → String?
-
no setter
Methods
-
copyWith(
{num? projectDocumentId, String? projectId, String? url, String? urlName, String? iconFull, String? icon, String? type, String? createdAt, bool isSelected = false}) → DocumentOtherData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited