Highlights class

Constructors

Highlights({num? projectId, String? name, String? tagLine, String? imageFull, String? image})
Highlights.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
image String?
no setter
imageFull String?
no setter
name String?
no setter
projectId num?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagLine String?
no setter

Methods

copyWith({num? projectId, String? name, String? tagLine, String? imageFull, String? image}) Highlights
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited