VirtualData class

Constructors

VirtualData({num? virtualId, num? projectId, String? type, String? title, String? tagLine, String? description, String? url, String? image, String? virtualImageName, String? createdAt})
VirtualData.fromJson(dynamic json)

Properties

createdAt String?
no setter
description String?
no setter
hashCode int
The hash code for this object.
no setterinherited
image String?
no setter
projectId num?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagLine String?
no setter
title String?
no setter
type String?
no setter
url String?
no setter
virtualId num?
no setter
virtualImageName String?
no setter

Methods

copyWith({num? virtualId, num? projectId, String? type, String? title, String? tagLine, String? description, String? url, String? image, String? virtualImageName, String? createdAt}) VirtualData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited