ProjectListResponse class

Constructors

ProjectListResponse({num? success, List<ProjectData>? data, num? totalRecords, String? message})
ProjectListResponse.fromJson(dynamic json)

Properties

data → List<ProjectData>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → num?
no setter
totalRecords → num?
no setter

Methods

copyWith({num? success, List<ProjectData>? data, num? totalRecords, String? message}) → ProjectListResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited