ConstructionData2 class
Constructors
- ConstructionData2({String? constructionId, String? title, String? description, String? tagLine, String? progressPercent, String? constructionDate})
- ConstructionData2.fromJson(dynamic json)
Properties
- constructionDate → String?
-
no setter
- constructionId → String?
-
no setter
- description → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- progressPercent → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tagLine → String?
-
no setter
- title → String?
-
no setter
Methods
-
copyWith(
{String? constructionId, String? title, String? description, String? tagLine, String? progressPercent, String? constructionDate}) → ConstructionData2 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited