ProjectResponseModel class

Constructors

ProjectResponseModel({List<DataList>? data, num? success, num? totalRecords, String? message})
ProjectResponseModel.fromJson(dynamic json)

Properties

data → List<DataList>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → num?
no setter
totalRecords → num?
no setter

Methods

copyWith({List<DataList>? data, num? success, num? totalRecords, String? message}) → ProjectResponseModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited