model/ProjectWebPageResponseModel library

Functions

amenitiesDataFromJson(String str) AmenitiesData
amenity_id : 35 amenity : "Indoor Game" icon : "https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671802198_11.svg"
amenitiesDataToJson(AmenitiesData data) String
amenitiesImagesFromJson(String str) AmenitiesImages
id : 89 project_id : "47" image : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/amenities/image/amenities_1674726357_95.jpg" image_name : "amenities_1674726357_95.jpg"
amenitiesImagesToJson(AmenitiesImages data) String
bannerDataFromJson(String str) BannerData
id : 1344 project_id : "47" title_display : "Experience Magical Living at The Crown
" title : "Experience Magical Living at The Crown\n" image_web_type : "image" image_mobile_type : "video" image_web : "banner_web_1671101599_75.jpg" image_web_full : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/banner/banner_web_1671101599_75.jpg" image_mobile : "banner_mobile_1654755176_49.mp4" image_mobile_full : "https://www.reecosys.com/assets/uploads/project/banner/banner_mobile_1654755176_49.mp4"
bannerDataToJson(BannerData data) String
bannerListFromJson(String str) BannerList
image : "banner_1649486170_96.jpg" image_full : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg"
bannerListToJson(BannerList data) String
blogDataFromJson(String str) BlogData
id : 8 project_id : "47" page_id : "" slug : "how-green-homes-make-summer-better" image : "banner_1683183199_43.jpg" image_full : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/blog/banner/banner_1683183199_43.jpg" banner_title : "How Green Homes Make Summer Better" title : "How Green Homes Make Summer Better" description : "
blogDataToJson(BlogData data) String
campaignArrayFromJson(String str) CampaignArray
cp_total : 3057 id : 20 project_id : "47" banner_name : "banner_1649506601_28.jpg" banner : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1649506601_28.jpg" banner_full : "https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1649506601_28.jpg" name : "The Crown" description : "" title : "Pre-launch" location : "Bhat" from_timestamp : "1649442600" to_timestamp : "1651257000" from_date : "09 Apr, 2022" from_date_time : "12:00 AM" to_date : "30 Apr, 2022" to_date_time : "12:00 AM" is_active : "1" is_deleted : "0" created_at_today : 0 created_at : "09 Apr, 2022" created_time : "05:19 PM" updated_at : "Apr 18, 2022" master_user_id : 1 text_color : "white" text_position : "center"
campaignArrayToJson(CampaignArray data) String
constructionData2FromJson(String str) ConstructionData2
construction_id : "25" title : "Construction Update" description : "" tag_line : "Update" progress_percent : "10" construction_date : ""
constructionData2ToJson(ConstructionData2 data) String
constructionFromJson(String str) Construction
title : "Construction Update" description : "" progress_percent : "10" tag_line : "Update" construction_date : ""
constructionToJson(Construction data) String
dataFromJson(String str) ProjectGetSet
share_url : {"construction":"","gallery":"shivalikgroup.com/project/thecrown/?type=gallery","website_url":"shivalikgroup.com/project/thecrown"} project_id : 47 project_name : "the crown" slug : "thecrown" project_title : "The Crown" project_title_small : "T" project_contact_no : "91 7575007335" project_type : "4 BHK" other_spaces_name : "" location : "Near Airport, Bhat" min_price : "" min_price_number : "" min_price_type : "" max_price : "" sqft_min_area : "495" sqft_max_area : "" size_price : "4 BHK Royal Green Homes" available_unit : "1" no_of_unit : "50" sqft_type : "Sq. Yd" rera_number : "PR/GJ/GANDHINAGAR/GANDHINAGAR/AUDA/RAA10006/040422" image : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg" image_full : "https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg" banner_list : {"image":"banner_1649486170_96.jpg","image_full":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg"} page_title : "4 BHK Flats in Bhat, Ahmedabad for Sale" location_title : "Address" location_tag_line : "Lane Besides Mother Dairy, Bhat" page_description : "Discover luxurious 4BHK flats in Bhat, Ahmedabad at The Crown Living. Enjoy modern interiors, amenities, and a prime location. Book now!" page_keywords : "4 BHK Flats in Bhat, Ahmedabad" page_image : "SEO_1662707305_54.jpg" page_image_upload : "SEO_1662707305_54.jpg" page_image_full : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/seo/image/SEO_1662707305_54.jpg" overview_title : "" description : "
dataToJson(ProjectGetSet data) String
documentOtherDataFromJson(String str) DocumentOtherData
project_document_id : 394 project_id : "47" url : "https://www.reecosys.com/assets/uploads/project/file/other_1674564729_30.pdf" url_name : "other_1674564729_30.pdf" icon_full : "" icon : "" type : "Brochure" created_at : "Mar 27, 2023"
documentOtherDataToJson(DocumentOtherData data) String
galleryDataFromJson(String str) GalleryData
project_gallery_id : 58 project_id : "47" title : "Gallery" title_array : "Gallery" tag_line : "A grand welcome for your gracious presence" type : "gallery" description : "" created_at : "Mar 22, 2022" image : {"image_id":2967,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_50.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_50.jpg","image_name":"gallery_1674473064_50.jpg","type":"gallery","title":"Reserve the prestigious green lifestyle","created_at":"Apr 13, 2023"},{"image_id":2968,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_16.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_16.jpg","image_name":"gallery_1674473064_16.jpg","type":"gallery","title":"Foyer","created_at":"Apr 13, 2023"},{"image_id":2969,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_49.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_49.jpg","image_name":"gallery_1674473064_49.jpg","type":"gallery","title":"Kids play area","created_at":"Apr 13, 2023"},{"image_id":2970,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_40.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_40.jpg","image_name":"gallery_1674473064_40.jpg","type":"gallery","title":"Drawing room","created_at":"Apr 13, 2023"},{"image_id":2971,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_86.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_86.jpg","image_name":"gallery_1674473064_86.jpg","type":"gallery","title":"Personal foyer","created_at":"Apr 13, 2023"},{"image_id":2972,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_69.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_69.jpg","image_name":"gallery_1674473064_69.jpg","type":"gallery","title":"Your royalty will be crowned with a prestigious address","created_at":"Apr 13, 2023"},{"image_id":2973,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_21.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_21.jpg","image_name":"gallery_1674473064_21.jpg","type":"gallery","title":"","created_at":"Apr 13, 2023"}
galleryDataToJson(GalleryData data) String
highlightsFromJson(String str) Highlights
project_id : 47 name : "4 BHK" tag_line : "Luxurious Apartments" image_full : "" image : ""
highlightsToJson(Highlights data) String
imageFromJson(String str) ImageProject
image_id : 2967 project_gallery_id : 58 project_id : 47 image : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_50.jpg" image_full : "https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_50.jpg" image_name : "gallery_1674473064_50.jpg" type : "gallery" title : "Reserve the prestigious green lifestyle" created_at : "Apr 13, 2023"
imageToJson(ImageProject data) String
otherProjectsFromJson(String str) OtherProjects
project_id : "1" project_title : "edge"
otherProjectsToJson(OtherProjects data) String
projectWebPageResponseModelFromJson(String str) ProjectWebPageResponseModel
data : [{"share_url":{"construction":"","gallery":"shivalikgroup.com/project/thecrown/?type=gallery","website_url":"shivalikgroup.com/project/thecrown"},"project_id":47,"project_name":"the crown","slug":"thecrown","project_title":"The Crown","project_title_small":"T","project_contact_no":"91 7575007335","project_type":"4 BHK","other_spaces_name":"","location":"Near Airport, Bhat","min_price":"","min_price_number":"","min_price_type":"","max_price":"","sqft_min_area":"495","sqft_max_area":"","size_price":"4 BHK Royal Green Homes","available_unit":"1","no_of_unit":"50","sqft_type":"Sq. Yd","rera_number":"PR/GJ/GANDHINAGAR/GANDHINAGAR/AUDA/RAA10006/040422","image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg","banner_list":{"image":"banner_1649486170_96.jpg","image_full":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg"},"page_title":"4 BHK Flats in Bhat, Ahmedabad for Sale","location_title":"Address","location_tag_line":"Lane Besides Mother Dairy, Bhat","page_description":"Discover luxurious 4BHK flats in Bhat, Ahmedabad at The Crown Living. Enjoy modern interiors, amenities, and a prime location. Book now!","page_keywords":"4 BHK Flats in Bhat, Ahmedabad","page_image":"SEO_1662707305_54.jpg","page_image_upload":"SEO_1662707305_54.jpg","page_image_full":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/seo/image/SEO_1662707305_54.jpg","overview_title":"","description":"
projectWebPageResponseModelToJson(ProjectWebPageResponseModel data) String
shareUrlFromJson(String str) ShareUrl
construction : "" gallery : "shivalikgroup.com/project/thecrown/?type=gallery" website_url : "shivalikgroup.com/project/thecrown"
shareUrlToJson(ShareUrl data) String
virtualDataFromJson(String str) VirtualData
virtual_id : 14 project_id : 47 type : "walk-through" title : "Project Walk-Through" tag_line : "" description : "
virtualDataToJson(VirtualData data) String