AmenitiesData class

Constructors

AmenitiesData({num? amenityId, String? amenity, String? icon})
AmenitiesData.fromJson(dynamic json)

Properties

amenity → String?
no setter
amenityId → num?
no setter
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({num? amenityId, String? amenity, String? icon}) → AmenitiesData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited