BlogData class

Constructors

BlogData({num? id, String? projectId, String? pageId, String? slug, String? image, String? imageFull, String? bannerTitle, String? title, String? description, String? seoTitle, String? seoDescription, String? seoKeywords, String? seoImage, String? seoImageFull, String? tagsArray, String? tagsCommaseparted, num? publishedTime, String? publishedDate, num? createdAtTime, String? dateFormat, String? dateTime, String? updatedAt, num? updatedAtTime, num? isActive, String? masterUserId})
BlogData.fromJson(dynamic json)

Properties

bannerTitle → String?
no setter
createdAtTime → num?
no setter
dateFormat → String?
no setter
dateTime → String?
no setter
description → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → num?
no setter
image → String?
no setter
imageFull → String?
no setter
isActive → num?
no setter
masterUserId → String?
no setter
pageId → String?
no setter
projectId → String?
no setter
publishedDate → String?
no setter
publishedTime → num?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seoDescription → String?
no setter
seoImage → String?
no setter
seoImageFull → String?
no setter
seoKeywords → String?
no setter
seoTitle → String?
no setter
slug → String?
no setter
tagsArray → String?
no setter
tagsCommaseparted → String?
no setter
title → String?
no setter
updatedAt → String?
no setter
updatedAtTime → num?
no setter

Methods

copyWith({num? id, String? projectId, String? pageId, String? slug, String? image, String? imageFull, String? bannerTitle, String? title, String? description, String? seoTitle, String? seoDescription, String? seoKeywords, String? seoImage, String? seoImageFull, String? tagsArray, String? tagsCommaseparted, num? publishedTime, String? publishedDate, num? createdAtTime, String? dateFormat, String? dateTime, String? updatedAt, num? updatedAtTime, num? isActive, String? masterUserId}) → BlogData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited