CampaignArray class

Constructors

CampaignArray({num? cpTotal, num? id, String? projectId, String? bannerName, String? banner, String? bannerFull, String? name, String? description, String? title, String? location, String? fromTimestamp, String? toTimestamp, String? fromDate, String? fromDateTime, String? toDate, String? toDateTime, String? isActive, String? isDeleted, num? createdAtToday, String? createdAt, String? createdTime, String? updatedAt, num? masterUserId, String? textColor, String? textPosition})
CampaignArray.fromJson(dynamic json)

Properties

no setter
bannerFull → String?
no setter
bannerName → String?
no setter
cpTotal → num?
no setter
createdAt → String?
no setter
createdAtToday → num?
no setter
createdTime → String?
no setter
description → String?
no setter
fromDate → String?
no setter
fromDateTime → String?
no setter
fromTimestamp → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → num?
no setter
isActive → String?
no setter
isDeleted → String?
no setter
location → String?
no setter
masterUserId → num?
no setter
name → String?
no setter
projectId → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → String?
no setter
textPosition → String?
no setter
title → String?
no setter
toDate → String?
no setter
toDateTime → String?
no setter
toTimestamp → String?
no setter
updatedAt → String?
no setter

Methods

copyWith({num? cpTotal, num? id, String? projectId, String? bannerName, String? banner, String? bannerFull, String? name, String? description, String? title, String? location, String? fromTimestamp, String? toTimestamp, String? fromDate, String? fromDateTime, String? toDate, String? toDateTime, String? isActive, String? isDeleted, num? createdAtToday, String? createdAt, String? createdTime, String? updatedAt, num? masterUserId, String? textColor, String? textPosition}) → CampaignArray
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited