GalleryData class

Constructors

GalleryData({num? projectGalleryId, String? projectId, String? title, List<String>? titleArray, String? tagLine, String? type, String? description, String? createdAt, List<ImageProject>? image})
GalleryData.fromJson(dynamic json)

Properties

createdAt → String?
no setter
description → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
image → List<ImageProject>?
no setter
projectGalleryId → num?
no setter
projectId → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagLine → String?
no setter
title → String?
no setter
titleArray → List<String>?
no setter
type → String?
no setter

Methods

copyWith({num? projectGalleryId, String? projectId, String? title, List<String>? titleArray, String? tagLine, String? type, String? description, String? createdAt, List<ImageProject>? image}) → GalleryData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited