ImageProject class

Constructors

ImageProject({num? imageId, num? projectGalleryId, num? projectId, String? image, String? imageFull, String? imageName, String? type, String? title, String? createdAt})
ImageProject.fromJson(dynamic json)

Properties

createdAt → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
image → String?
no setter
imageFull → String?
no setter
imageId → num?
no setter
imageName → String?
no setter
projectGalleryId → num?
no setter
projectId → num?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
no setter
type → String?
no setter

Methods

copyWith({num? imageId, num? projectGalleryId, num? projectId, String? image, String? imageFull, String? imageName, String? type, String? title, String? createdAt}) → ImageProject
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited