dataFromJson function

ProjectGetSet dataFromJson(
  1. String str
)

share_url : {"construction":"","gallery":"shivalikgroup.com/project/thecrown/?type=gallery","website_url":"shivalikgroup.com/project/thecrown"} project_id : 47 project_name : "the crown" slug : "thecrown" project_title : "The Crown" project_title_small : "T" project_contact_no : "91 7575007335" project_type : "4 BHK" other_spaces_name : "" location : "Near Airport, Bhat" min_price : "" min_price_number : "" min_price_type : "" max_price : "" sqft_min_area : "495" sqft_max_area : "" size_price : "4 BHK Royal Green Homes" available_unit : "1" no_of_unit : "50" sqft_type : "Sq. Yd" rera_number : "PR/GJ/GANDHINAGAR/GANDHINAGAR/AUDA/RAA10006/040422" image : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg" image_full : "https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg" banner_list : {"image":"banner_1649486170_96.jpg","image_full":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/banner/banner_1649486170_96.jpg"} page_title : "4 BHK Flats in Bhat, Ahmedabad for Sale" location_title : "Address" location_tag_line : "Lane Besides Mother Dairy, Bhat" page_description : "Discover luxurious 4BHK flats in Bhat, Ahmedabad at The Crown Living. Enjoy modern interiors, amenities, and a prime location. Book now!" page_keywords : "4 BHK Flats in Bhat, Ahmedabad" page_image : "SEO_1662707305_54.jpg" page_image_upload : "SEO_1662707305_54.jpg" page_image_full : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/seo/image/SEO_1662707305_54.jpg" overview_title : "" description : "

#royalgreenhomes

\n\n

Made in perfection, THE CROWN is a residential property with an ultra-luxurious arena in Bhat.
\nCelebrate the Essence of life with Royalty. Experience the kingship, comfort and elegance of spacious living.

\n\n

It's not years in your lifestyle but the lifestyle in your years that makes it memorable and every day feels like a crown moment to live at THE CROWN. Live Royal

\n" description_pain : "#royalgreenhomes

\n\nMade in perfection, THE CROWN is a residential property with an ultra-luxurious arena in Bhat.

\nCelebrate the Essence of life with Royalty. Experience the kingship, comfort and elegance of spacious living.

\n\nIt's not years in your lifestyle but the lifestyle in your years that makes it memorable and every day feels like a crown moment to live at THE CROWN. Live Royal

\n" big_text : "

The crown is a landmark of the Royal lifestyle designed to cater to your luxurious needs. Made with perfection, The Crown is a prestigious residential property in the ultra-luxurious arena of Bhat. Experience the Kingship, comfort & epitome of spacious living. Your everyday lifestyle will be made majestic in regal ways as you get crowned with a lavish life.

\n" big_text_pain : "The crown is a landmark of the Royal lifestyle designed to cater to your luxurious needs. Made with perfection, The Crown is a prestigious residential property in the ultra-luxurious arena of Bhat. Experience the Kingship, comfort & epitome of spacious living. Your everyday lifestyle will be made majestic in regal ways as you get crowned with a lavish life.

\n" summary : "" amenities_description : "

Crowned With
\nPlethora Of Amenities

\n" amenities_title : "Features and Amenities" amenities_tagline : "Landmark Crowned With Plethora Of Amenities" amenities_image : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/amenities/image/amenity_1649242583_32.jpg" whatsapp_link : null whatsapp_description : null other_project_id : "" map_slug : "https://www.google.com/maps/place/The+Crown/@23.0955097,72.6250151,17z/data=!3m1!4b1!4m5!3m4!1s0x395e81b22ca66c6d:0x47a51d0a5d91f466!8m2!3d23.0955097!4d72.6272038?shorturl=1" map_iframe : "https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d3670.0433277809716!2d72.6272038!3d23.0955097!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x395e81b22ca66c6d%3A0x47a51d0a5d91f466!2sThe%20Crown!5e0!3m2!1sen!2sin!4v1669697500013!5m2!1sen!2sin" map_sort_description : "Your Royaly will be Crowned with a Prestigious Address" map_image : "map_1655458147_65.jpg" map_image_full : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/map/map_1655458147_65.jpg" project_logo : "logo_1652805149_48.png" project_logo_full : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/logo/logo_1652805149_48.png" inquiry_image : "inquiry_1654800045_25.jpg" inquiry_image_full : "https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/inquiry/inquiry_1654800045_25.jpg" location_description : "" address_description : "" sort : 1 is_active : 1 created_at : "22 Mar, 2022" created_time : "09:35 PM" updated_at : "20 Apr, 2023" updated_time : "11:36 AM" download_title : "Let's Connect" download_tag_line : "" highlights_name : "" highlights_tag_line : "" highlights_description : "" other_projects : {"project_id":"1","project_title":"edge"},{"project_id":"2","project_title":"Parkview 2"},{"project_id":"3","project_title":"Platinum"},{"project_id":"4","project_title":"Harmony"},{"project_id":"5","project_title":"Enclave"},{"project_id":"13","project_title":"Shivalik Shilp-II"},{"project_id":"14","project_title":"shivalik shilp"},{"project_id":"15","project_title":"shivalik satyamev"},{"project_id":"35","project_title":"Green View"},{"project_id":"174","project_title":"Shivalik Skyview"},{"project_id":"175","project_title":"Upcoming at GIFT City"},{"project_id":"176","project_title":"Upcoming Near KeshavBaug Party Plot"},{"project_id":"177","project_title":"Upcoming Residential"},{"project_id":"178","project_title":"Universal Project"},{"project_id":"192","project_title":"SIRE"},{"project_id":"193","project_title":"Shivalik Avenue"},{"project_id":"194","project_title":"Shivalik Lakeview"},{"project_id":"195","project_title":"Shivalik Legacy"},{"project_id":"196","project_title":"Shivalik Paradise"},{"project_id":"197","project_title":"Shivalik Residences"},{"project_id":"198","project_title":"Shivalik Square"},{"project_id":"199","project_title":"Shivalik Sharda Parkview"} admin_module_id : "1" project_category_id : "36" category_id : "12" category : "residential" construction : {"title":"Construction Update","description":"","progress_percent":"10","tag_line":"Update","construction_date":""} construction_data_2 : {"construction_id":"25","title":"Construction Update","description":"","tag_line":"Update","progress_percent":"10","construction_date":""} project_status_id : "35" status_id : "1" status : "under construction" document_other_data : {"project_document_id":394,"project_id":"47","url":"https://www.reecosys.com/assets/uploads/project/file/other_1674564729_30.pdf","url_name":"other_1674564729_30.pdf","icon_full":"","icon":"","type":"Brochure","created_at":"Mar 27, 2023"} gallery_data : [{"project_gallery_id":58,"project_id":"47","title":"Gallery","title_array":"Gallery","tag_line":"A grand welcome for your gracious presence","type":"gallery","description":"","created_at":"Mar 22, 2022","image":{"image_id":2967,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_50.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_50.jpg","image_name":"gallery_1674473064_50.jpg","type":"gallery","title":"Reserve the prestigious green lifestyle","created_at":"Apr 13, 2023"},{"image_id":2968,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_16.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_16.jpg","image_name":"gallery_1674473064_16.jpg","type":"gallery","title":"Foyer","created_at":"Apr 13, 2023"},{"image_id":2969,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_49.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_49.jpg","image_name":"gallery_1674473064_49.jpg","type":"gallery","title":"Kids play area","created_at":"Apr 13, 2023"},{"image_id":2970,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_40.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_40.jpg","image_name":"gallery_1674473064_40.jpg","type":"gallery","title":"Drawing room","created_at":"Apr 13, 2023"},{"image_id":2971,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_86.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_86.jpg","image_name":"gallery_1674473064_86.jpg","type":"gallery","title":"Personal foyer","created_at":"Apr 13, 2023"},{"image_id":2972,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_69.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_69.jpg","image_name":"gallery_1674473064_69.jpg","type":"gallery","title":"Your royalty will be crowned with a prestigious address","created_at":"Apr 13, 2023"},{"image_id":2973,"project_gallery_id":58,"project_id":47,"image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_21.jpg","image_full":"https://www.reecosys.com/assets/uploads/project/images/gallery_1674473064_21.jpg","image_name":"gallery_1674473064_21.jpg","type":"gallery","title":"","created_at":"Apr 13, 2023"}}] virtual_data : {"virtual_id":14,"project_id":47,"type":"walk-through","title":"Project Walk-Through","tag_line":"","description":"<p>NOT EVERYONE CAN OWN</p>\n","url":"https://www.youtube.com/embed/TDmAZ0hvFn8","image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/virtual/virtual_1652804948_95.jpg","virtual_image_name":"virtual_1652804948_95.jpg","created_at":"Apr 06, 2022"} amenities_data : {"amenity_id":35,"amenity":"Indoor Game","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671802198_11.svg"},{"amenity_id":43,"amenity":"Mini Theater","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671802489_80.svg"},{"amenity_id":64,"amenity":"Swimming Pool","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671802695_30.svg"},{"amenity_id":57,"amenity":"Senior Citizen Park","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671802402_87.svg"},{"amenity_id":12,"amenity":"Children's Play Area","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671801288_29.svg"},{"amenity_id":41,"amenity":"Medicare Center","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671801552_23.svg"},{"amenity_id":90,"amenity":"Yoga spa, baby creche","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671802583_98.svg"},{"amenity_id":92,"amenity":"Pick-up & Drop-off","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671802447_93.svg"},{"amenity_id":91,"amenity":"Party lawn","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671802453_85.svg"},{"amenity_id":93,"amenity":"Utility store","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671802671_37.svg"},{"amenity_id":89,"amenity":"3 Gardens","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671800964_87.svg"},{"amenity_id":88,"amenity":"Basket ball court","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671801021_90.svg"},{"amenity_id":87,"amenity":"Cricket net","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671801322_60.svg"},{"amenity_id":86,"amenity":"Fitness center","icon":"https://www.reecosys.com/assets/uploads/project/amenities/amenity_1671801752_38.svg"} amenities_array : 35,43,64,57,12,41,90,92,91,93,89,88,87,86 highlights : {"project_id":47,"name":"4 BHK","tag_line":"Luxurious Apartments","image_full":"","image":""},{"project_id":47,"name":"4","tag_line":"BHK & Penthouse","image_full":"","image":""},{"project_id":47,"name":"Italian","tag_line":"Marble in Drawing Dining","image_full":"","image":""},{"project_id":47,"name":"2","tag_line":"Large Balconies","image_full":"","image":""},{"project_id":47,"name":"3","tag_line":"Gardens Total 28,000 Sq ft","image_full":"","image":""},{"project_id":47,"name":"Green","tag_line":"Building","image_full":"","image":""},{"project_id":47,"name":"2.30 Cr*","tag_line":"Onwards","image_full":"","image":""} amenities_images : {"id":89,"project_id":"47","image":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/amenities/image/amenities_1674726357_95.jpg","image_name":"amenities_1674726357_95.jpg"} banner_data : {"id":1344,"project_id":"47","title_display":"Experience Magical Living at The Crown
","title":"Experience Magical Living at The Crown\n","image_web_type":"image","image_mobile_type":"video","image_web":"banner_web_1671101599_75.jpg","image_web_full":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/project/banner/banner_web_1671101599_75.jpg","image_mobile":"banner_mobile_1654755176_49.mp4","image_mobile_full":"https://www.reecosys.com/assets/uploads/project/banner/banner_mobile_1654755176_49.mp4"} total_inquiries : 946 campaign_array : {"cp_total":3057,"id":20,"project_id":"47","banner_name":"banner_1649506601_28.jpg","banner":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1649506601_28.jpg","banner_full":"https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1649506601_28.jpg","name":"The Crown","description":"","title":"Pre-launch","location":"Bhat","from_timestamp":"1649442600","to_timestamp":"1651257000","from_date":"09 Apr, 2022","from_date_time":"12:00 AM","to_date":"30 Apr, 2022","to_date_time":"12:00 AM","is_active":"1","is_deleted":"0","created_at_today":0,"created_at":"09 Apr, 2022","created_time":"05:19 PM","updated_at":"Apr 18, 2022","master_user_id":1,"text_color":"white","text_position":"center"},{"cp_total":3057,"id":23,"project_id":"47","banner_name":"banner_1651910986_68.jpg","banner":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1651910986_68.jpg","banner_full":"https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1651910986_68.jpg","name":"The Crown","description":"","title":"The Crown","location":"Bhat","from_timestamp":"1651861800","to_timestamp":"1652466600","from_date":"07 May, 2022","from_date_time":"12:00 AM","to_date":"14 May, 2022","to_date_time":"12:00 AM","is_active":"1","is_deleted":"0","created_at_today":0,"created_at":"07 May, 2022","created_time":"01:56 PM","updated_at":"","master_user_id":1,"text_color":"white","text_position":"center"},{"cp_total":3057,"id":26,"project_id":"47","banner_name":"banner_1654493792_78.jpg","banner":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1654493792_78.jpg","banner_full":"https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1654493792_78.jpg","name":"The Crown","description":"","title":"Luxurious Living","location":"Bhat","from_timestamp":"1654453800","to_timestamp":"1654972200","from_date":"06 Jun, 2022","from_date_time":"12:00 AM","to_date":"12 Jun, 2022","to_date_time":"12:00 AM","is_active":"1","is_deleted":"0","created_at_today":0,"created_at":"06 Jun, 2022","created_time":"11:18 AM","updated_at":"","master_user_id":1,"text_color":"black","text_position":"center"},{"cp_total":3057,"id":32,"project_id":"47","banner_name":"banner_1657890021_57.jpg","banner":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1657890021_57.jpg","banner_full":"https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1657890021_57.jpg","name":"The Crown","description":"","title":"Location Campaign","location":"Bhat","from_timestamp":"1657909800","to_timestamp":"1658514600","from_date":"16 Jul, 2022","from_date_time":"12:00 AM","to_date":"23 Jul, 2022","to_date_time":"12:00 AM","is_active":"1","is_deleted":"0","created_at_today":0,"created_at":"15 Jul, 2022","created_time":"06:56 PM","updated_at":"","master_user_id":1,"text_color":"white","text_position":"center"},{"cp_total":3057,"id":37,"project_id":"47","banner_name":"banner_1660996640_1.jpg","banner":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1660996640_1.jpg","banner_full":"https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1660996640_1.jpg","name":"The Crown","description":"","title":"Large Balcony & Personal elevator","location":"Bhat","from_timestamp":"1660933800","to_timestamp":"1661538600","from_date":"20 Aug, 2022","from_date_time":"12:00 AM","to_date":"27 Aug, 2022","to_date_time":"12:00 AM","is_active":"1","is_deleted":"0","created_at_today":0,"created_at":"20 Aug, 2022","created_time":"05:38 PM","updated_at":"","master_user_id":1,"text_color":"white","text_position":"center"},{"cp_total":3057,"id":44,"project_id":"47","banner_name":"banner_1674899799_49.jpg","banner":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1674899799_49.jpg","banner_full":"https://www.reecosys.com/assets/uploads/cp_campaign/banner/banner_1674899799_49.jpg","name":"The Crown","description":"","title":"Mahel Jaisa ghar","location":"Bhat","from_timestamp":"1674844200","to_timestamp":"1675449000","from_date":"28 Jan, 2023","from_date_time":"12:00 AM","to_date":"04 Feb, 2023","to_date_time":"12:00 AM","is_active":"1","is_deleted":"0","created_at_today":0,"created_at":"28 Jan, 2023","created_time":"03:30 PM","updated_at":"May 04, 2023","master_user_id":1,"text_color":"white","text_position":"center"} sub_category : "94" blog_data : {"id":8,"project_id":"47","page_id":"","slug":"how-green-homes-make-summer-better","image":"banner_1683183199_43.jpg","image_full":"https://www.reecosys.com/api/image-tool/index.php?src=https://www.reecosys.com/assets/uploads/blog/banner/banner_1683183199_43.jpg","banner_title":"How Green Homes Make Summer Better","title":"How Green Homes Make Summer Better","description":"<p>The summer heat in Gujarat can be quite intense at times, especially during the peak of the season. It&#39;s a must to have a comfortable living space that can keep you cool and relaxed during the hot months.&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>The Shivalik Group has focused on creating green buildings that are eco-friendly and sustainable. Majority of our projects have been developed with a sustainable future in mind. Let&#39;s first begin by understanding what green building is.&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>What is a Green Building?</p>\n\n<p>&quot;Green buildings&quot; refer to spaces that are environmentally friendly and sustainable.</p>\n\n<p>&nbsp;</p>\n\n<p>These spaces make efficient use of natural resources such as sunlight, water, and construction materials and techniques.&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>&quot;Green Building&quot; ensures minimal negative environmental impacts compared to traditional construction. Green houses are also cost-effective, low-maintenance cost, and self-sufficient. Let&#39;s take a look at some of the benefits of green homes during the summer season.</p>\n\n<p>&nbsp;</p>\n\n<p>The Benefits of Green Homes During the Summer&nbsp;</p>\n\n<p>Save Money on AC Bills</p>\n\n<p>Unlike traditional homes, green homes are designed to be power-efficient, thus reducing the need for air conditioning. By using high-quality insulation materials, these homes maintain a constant temperature, reducing the load on air conditioners.&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>Installing energy-efficient openings in a green home helps to keep the interior temperature stable, thereby cutting down on the need for air conditioning. This not only leads to lower electricity bills, but also contributes to reducing one&#39;s carbon footprint.</p>\n\n<p>&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>Keeping cool with shades</p>\n\n<p>The shading systems used in green homes reduce the amount of heat entering the house. Trees may be planted around the property to shade the property along with external shades, overhangs, or other structures.&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>A shading system keeps the indoor temperature comfortable and prevents the sun&#39;s rays from entering the house.</p>\n\n<p>&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>Make Your Home Brighter with Natural Light</p>\n\n<p>Green homes incorporate natural lighting through large windows and skylights. This not only reduces the need for artificial lighting but also has several health benefits. Natural light can improve your mood, increase productivity, and promote better sleep. It&#39;s a simple and effective way to make your home more sustainable and comfortable.</p>\n\n<p>&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>Take a Step Toward a Green Lifestyle</p>\n\n<p>Living an eco-friendly lifestyle doesn&#39;t require drastic changes. Every little move helps! There are numerous techniques to make your living space more sustainable, such as opting for energy-efficient LED lighting and conserving water. These small, yet impactful, steps will contribute to a greener tomorrow.</p>\n\n<p>&nbsp;</p>\n\n<p>&nbsp;</p>\n\n<p>We at the Shivalik Group encourage homeowners to make small changes that add up to big results. The Shivalik Group is committed to creating sustainable homes that offer residents a green and comfortable living experience.&nbsp;</p>\n\n<p><br />\n&nbsp;</p>\n\n<p>Visit our website https://www.shivalikgroup.com/projects/ to learn more about our environmentally friendly initiatives, and let&#39;s do our part to make this planet a better place to live.&nbsp;</p>\n\n<p><br />\nThis is your chance to &#39;Own the Green&#39; with us!</p>\n","seo_title":"How Green Homes Make Summer Better","seo_description":"How Green Homes Make Summer Better","seo_keywords":"How Green Homes Make Summer Better","seo_image":"","seo_image_full":"","tags_array":"","tags_commaseparted":"","published_time":1683052200,"published_date":"03 May, 2023","created_at_time":1683183199,"date_format":"","date_time":"12:23 PM","updated_at":"May 09, 2023","updated_at_time":1683611046,"is_active":1,"master_user_id":"1"}

Implementation

ProjectGetSet dataFromJson(String str) => ProjectGetSet.fromJson(json.decode(str));