DataQuaterDropDown class

Constructors

DataQuaterDropDown({String? id, String? name, bool? isSelected, List<Sub>? sub})
DataQuaterDropDown.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
isSelected bool?
no setter
isSelectedData bool
no getter
name String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sub List<Sub>?
no setter

Methods

copyWith({String? id, String? name, bool? isSelected, List<Sub>? sub}) DataQuaterDropDown
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited