RelationsResponseModel class

Constructors

RelationsResponseModel({List<Data>? data, num? success, String? message})
RelationsResponseModel.fromJson(dynamic json)

Properties

data → List<Data>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → num?
no setter

Methods

copyWith({List<Data>? data, num? success, String? message}) → RelationsResponseModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited