ShareUnitPdfResponseModel class

Constructors

ShareUnitPdfResponseModel({num? success, String? filePath})
ShareUnitPdfResponseModel.fromJson(dynamic json)

Properties

filePath → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → num?
no setter

Methods

copyWith({num? success, String? filePath}) → ShareUnitPdfResponseModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited