StaffDetailData class

Constructors

StaffDetailData({String? name, String? contactNumber, String? email, String? companyName, String? dateOfBirth, String? gender, String? department, String? designation, String? cl, String? pl})
StaffDetailData.fromJson(dynamic json)

Properties

cl String?
no setter
companyName String?
no setter
contactNumber String?
no setter
dateOfBirth String?
no setter
department String?
no setter
designation String?
no setter
email String?
no setter
gender String?
no setter
hashCode int
The hash code for this object.
no setterinherited
name String?
no setter
pl String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? contactNumber, String? email, String? companyName, String? dateOfBirth, String? gender, String? department, String? designation, String? cl, String? pl}) StaffDetailData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited