StateListResponseModel class

Constructors

StateListResponseModel({num? success, String? message, List<StateData>? stateData})
StateListResponseModel.fromJson(dynamic json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateData → List<StateData>?
no setter
success → num?
no setter

Methods

copyWith({num? success, String? message, List<StateData>? stateData}) → StateListResponseModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited