TaskListData class

Constructors

TaskListData({String? task, String? inquiryTaskId, num? adminModuleId, String? inquiryType, String? showActivity, String? showFollowUpDate, String? showUnitNo, String? showLostReason, bool isActivated = false, bool isSelected = false, String? showPriority})
TaskListData.fromJson(dynamic json)

Properties

adminModuleId → num?
no setter
hashCode → int
The hash code for this object.
no setterinherited
inquiryTaskId → String?
no setter
inquiryType → String?
no setter
isActivated ↔ bool
getter/setter pair
isSelected ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showActivity → String?
no setter
showFollowUpDate → String?
no setter
showLostReason → String?
no setter
showPriority → String?
no setter
showUnitNo → String?
no setter
task → String?
no setter

Methods

copyWith({String? task, String? inquiryTaskId, num? adminModuleId, String? inquiryType, String? showActivity, String? showFollowUpDate, String? showUnitNo, String? showLostReason, bool isActivated = false, bool isSelected = false, String? showPriority}) → TaskListData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited