menu
reecosys_app package
documentation
model/TrainingListResponseModel.dart
Files class
Files class
dark_mode
light_mode
Files
class
Constructors
Files
({
String
?
file
,
String
?
title
})
Files.fromJson
(
dynamic
json
)
Properties
file
→
String
?
no setter
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
title
→
String
?
no setter
Methods
copyWith
(
{
String
?
file
,
String
?
title
})
→
Files
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
reecosys_app package
documentation
model/TrainingListResponseModel
Files class
TrainingListResponseModel library