VideosLink class

Constructors

VideosLink({String? url, String? title, String? urlThumnail})
VideosLink.fromJson(dynamic json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
no setter
url → String?
no setter
urlThumnail → String?
no setter

Methods

copyWith({String? url, String? title, String? urlThumnail}) → VideosLink
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited