MultiSelectionModel class

Constructors

MultiSelectionModel({required String titleStatic, required bool isSelectStatic})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSelect ↔ bool
getter/setter pair
isSelected ← bool
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited