Yyyyy class
Constructors
-
Yyyyy({List<
InquiryTypes> ? inquiryTypes}) - Yyyyy.fromJson(dynamic json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inquiryTypes
→ List<
InquiryTypes> ? -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< InquiryTypes> ? inquiryTypes}) → Yyyyy -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited