Indicator constructor

Indicator({
  1. required AnimationController normalController,
  2. required AnimationController highlightedController,
  3. int index = 0,
})

normalController Animation controller when state changes to normal highlightedController Animation controller when state changes to selected widget Indicator widget builder Widgetbuilder object index Determine index on the stack

Implementation

Indicator({
  required this.normalController,
  required this.highlightedController,
  this.index = 0,
});