SessionManager class
Constructors
Properties
- authToken → String
-
final
- contactNo → String
-
final
- deviceToken → String
-
final
- email → String
-
final
- groupId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → String
-
final
- isCP → String
-
final
- isCPNew → String
-
final
- isHintVisible → String
-
final
- isLoggedIn → String
-
final
- isNewTagVisible → String
-
final
- isUserFilter → String
-
final
- logo → String
-
final
- masterUserId → String
-
final
- name → String
-
final
- nameSmall → String
-
final
- notificationCount → String
-
final
- projectAssign → String
-
final
- refUserId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedDateFilter → String
-
final
Methods
-
checkIsLoggedIn(
) → bool? -
checkValidString(
String? value) → dynamic -
createLoginSession(
String masterUserIdApi, String groupIdApi, String isActiveApi, String refUserIdApi, String nameApi, String nameSmallApi, String emailApi, String contactNoApi, String logoApi, String authTokenApi) → Future -
getAuthToken(
) → String -
getContactNo(
) → String -
getDateFilterValue(
) → String -
getDeviceToken(
) → String -
getEmail(
) → String -
getGroupId(
) → String -
getIsActive(
) → String -
getIsCP(
) → bool? -
getIsCPNew(
) → bool? -
getIsHintVisible(
) → bool? -
getIsTagVisible(
) → bool? -
getIsUserFilterVisible(
) → bool? -
getMasterUserId(
) → String -
getName(
) → String -
getProfilePic(
) → String -
getProjectAssign(
) → String -
getRefUserId(
) → String -
getSmallName(
) → String -
getUnreadNotificationCount(
) → int? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAuthToken(
String apiAuthToken) → Future< void> -
setContactNo(
String apiMobileNumber) → Future< void> -
setDateFilterValue(
String value) → Future< void> -
setDeviceToken(
String apiDeviceToken) → Future< void> -
setEmail(
String apiEmail) → Future< void> -
setGroupId(
String data) → Future< void> -
setIsActive(
String data) → Future< void> -
setIsCP(
bool isCPApi) → Future< void> -
setIsCPNew(
bool isCPApi) → Future< void> -
setIsHintVisible(
bool isHintVisibleApi) → Future< void> -
setIsLoggedIn(
bool isLogin) → Future< void> -
setIsTagVisible(
bool apiIsNewTagVisible) → Future< void> -
setIsUserFilterVisible(
bool isUserFilterApi) → Future< void> -
setMasterUserId(
String data) → Future< void> -
setName(
String data) → Future< void> -
setProfilePic(
String apiMobileNumber) → Future< void> -
setProjectAssign(
String data) → Future< void> -
setRefUserId(
String data) → Future< void> -
setSmallName(
String data) → Future< void> -
setUnreadNotificationCount(
int count) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited