SessionManagerMethods class

Constructors

SessionManagerMethods()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clear() → Future<bool?>
getBool(String key) → bool?
getDouble(String key) → double?
getInt(String key) → int?
getString(String key) → String?
getStringList(String key) → List<String>?
init() → Future<SharedPreferences?>
remove(String key) → Future<bool?>
setBool(String key, bool value) → Future<bool?>
setDouble(String key, double value) → Future<bool?>
setInt(String key, int value) → Future<bool?>
setString(String key, String value) → Future<bool?>
setStringList(String key, List<String> value) → Future<bool?>