ProjectTabOld class

Inheritance

Constructors

ProjectTabOld(List<ProjectList> getSet, StateSetter setState, BuildContext context, void getUnitsClick(ProjectList getSet), void getShareClick(ProjectList getSet), void getDownloadClick(ProjectList getSet), void getInquiryClick(ProjectList getSet, String type), String masterUserId, {Key? key})

Properties

context BuildContext
final
getDownloadClick → void Function(ProjectList getSet)
final
getInquiryClick → void Function(ProjectList getSet, String type)
final
getSet List<ProjectList>
final
getShareClick → void Function(ProjectList getSet)
final
getUnitsClick → void Function(ProjectList getSet)
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
masterUserId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setState StateSetter
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
checkImageLenth(List<String> list) → dynamic
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getFavProject(ProjectList getSet) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
projectBlockNew(int index, void setState(VoidCallback fn), List<ProjectList> dataList) → dynamic
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited