ActivityListData class
Constructors
- ActivityListData({String? activity, String? inquiryActivityId, bool isSelected = false})
- ActivityListData.fromJson(dynamic json)
Properties
- activity → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inquiryActivityId → String?
-
no setter
- isSelected ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? activity, String? inquiryActivityId, bool isSelected = false}) → ActivityListData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited