AddressListResponseModel class

Constructors

AddressListResponseModel({List<AddressListData>? addressListData, num? success, String? message})
AddressListResponseModel.fromJson(dynamic json)

Properties

addressListData List<AddressListData>?
no setter
hashCode int
The hash code for this object.
no setterinherited
message String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success num?
no setter

Methods

copyWith({List<AddressListData>? addressListData, num? success, String? message}) AddressListResponseModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited