AllInquiriesResponseModel class
Constructors
-
AllInquiriesResponseModel({List<
DataList> ? data, List<StageTab> ? stageTab, List<PriorityTab> ? priorityTab, num? success, String? message, num? totalRecords, num? totalRecordsAsPerColumn, LeadTotal? leadTotal, List<LeadTab> ? leadTab}) - AllInquiriesResponseModel.fromJson(dynamic json)
Properties
-
data
→ List<
DataList> ? -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
leadTab
→ List<
LeadTab> ? -
no setter
- leadTotal → LeadTotal?
-
no setter
- message → String?
-
no setter
-
priorityTab
→ List<
PriorityTab> ? -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stageTab
→ List<
StageTab> ? -
no setter
- success → num?
-
no setter
- totalRecords → num?
-
no setter
- totalRecordsAsPerColumn → num?
-
no setter
Methods
-
copyWith(
{List< DataList> ? data, num? success, List<StageTab> ? stageTab, List<PriorityTab> ? priorityTab, String? message, num? totalRecords, LeadTotal? leadTotal, List<LeadTab> ? leadTab}) → AllInquiriesResponseModel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited