AllInquiryResponse class
Constructors
-
AllInquiryResponse({List<
StageTab> ? stageTab, List<PriorityTab> ? priorityTab, List<DataList> ? data, num? success, String? message, num? totalRecords, num? totalRecordsAsPerColumn}) - AllInquiryResponse.fromJson(dynamic json)
Properties
-
data
→ List<
DataList> ? -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
no setter
-
priorityTab
→ List<
PriorityTab> ? -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stageTab
→ List<
StageTab> ? -
no setter
- success → num?
-
no setter
- totalRecords → num?
-
no setter
- totalRecordsAsPerColumn → num?
-
no setter
Methods
-
copyWith(
{List< StageTab> ? stageTab, List<PriorityTab> ? priorityTab, List<DataList> ? data, num? success, String? message, num? totalRecords, num? totalRecordsAsPerColumn}) → AllInquiryResponse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited