Notification class

Constructors

Notification({String? isNotification, String? title, String? message, String? date, String? time})
Notification.fromJson(dynamic json)

Properties

date String?
no setter
hashCode int
The hash code for this object.
no setterinherited
isNotification String?
no setter
message String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String?
no setter
title String?
no setter

Methods

copyWith({String? isNotification, String? title, String? message, String? date, String? time}) Notification
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited