Data class
Constructors
Properties
- appType → String?
-
no setter
- createdAt → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → num?
-
no setter
- isFource → num?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
no setter
- version → String?
-
no setter
Methods
-
copyWith(
{num? id, String? version, String? type, num? isFource, String? appType, String? createdAt}) → Data -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited