Data class

Constructors

Data({String? bankAccountID, String? masterUserId, String? type, String? iFSCCode, String? accountNumber, String? bankName, String? branchName, String? isPrimaryAccount, String? bankProof, String? bankProofFull})
Data.fromJson(dynamic json)

Properties

accountNumber String?
no setter
bankAccountID String?
no setter
bankName String?
no setter
bankProof String?
no setter
bankProofFull String?
no setter
branchName String?
no setter
hashCode int
The hash code for this object.
no setterinherited
iFSCCode String?
no setter
isPrimaryAccount String?
no setter
masterUserId String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setter

Methods

copyWith({String? bankAccountID, String? masterUserId, String? type, String? iFSCCode, String? accountNumber, String? bankName, String? branchName, String? isPrimaryAccount, String? bankProof, String? bankProofFull}) Data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited