CPListData class
Constructors
- CPListData({num? userId, String? cpCode, String? firstName, String? lastName, String? contactNo, String? address, String? emailAddress, String? profileImage, String? status, num? verify, String? type, String? companyId, String? companyName, String? birthdate, String? birthdateTime, num? createdAtToday, String? createdAt, String? createdTime, num? masterUserId, String? isCrown, String? isReinquiry, dynamic commentAdmin, dynamic masterCpId})
- CPListData.fromJson(dynamic json)
Properties
- address → String?
-
no setter
- birthdate → String?
-
no setter
- birthdateTime → String?
-
no setter
- commentAdmin → dynamic
-
no setter
- companyId → String?
-
no setter
- companyName → String?
-
no setter
- contactNo → String?
-
no setter
- cpCode → String?
-
no setter
- createdAt → String?
-
no setter
- createdAtToday → num?
-
no setter
- createdTime → String?
-
no setter
- emailAddress → String?
-
no setter
- firstName → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCrown → String?
-
no setter
- isReinquiry → String?
-
no setter
- lastName → String?
-
no setter
- masterCpId → dynamic
-
no setter
- masterUserId → num?
-
no setter
- profileImage → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
no setter
- type → String?
-
no setter
- userId → num?
-
no setter
- verify → num?
-
no setter
Methods
-
copyWith(
{num? userId, String? cpCode, String? firstName, String? lastName, String? contactNo, String? address, String? emailAddress, String? profileImage, String? status, num? verify, String? type, String? companyId, String? companyName, String? birthdate, String? birthdateTime, num? createdAtToday, String? createdAt, String? createdTime, num? masterUserId, String? isCrown, String? isReinquiry, dynamic commentAdmin, dynamic masterCpId}) → CPListData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited