BannerData class

Constructors

BannerData({num? id, String? projectId, String? titleDisplay, String? title, String? imageWebType, String? imageMobileType, String? imageWeb, String? imageWebFull})
BannerData.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
id num?
no setter
imageMobileType String?
no setter
imageWeb String?
no setter
imageWebFull String?
no setter
imageWebType String?
no setter
projectId String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
no setter
titleDisplay String?
no setter

Methods

copyWith({num? id, String? projectId, String? titleDisplay, String? title, String? imageWebType, String? imageMobileType, String? imageWeb, String? imageWebFull}) BannerData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited