DeveloperList class

Constructors

DeveloperList({String? masterUserId, String? groupId, String? name, String? userName, String? email, num? isFavoriteMark, String? contactNo, String? birthdate, String? accountName, String? isActive, String? profileImage, bool isSelected = false, String? createdAt, List<Categories>? categories, List<BannerData>? bannerData})
DeveloperList.fromJson(dynamic json)

Properties

accountName String?
no setter
bannerData List<BannerData>?
no setter
birthdate String?
no setter
categories List<Categories>?
no setter
contactNo String?
no setter
createdAt String?
no setter
email String?
no setter
groupId String?
no setter
hashCode int
The hash code for this object.
no setterinherited
isActive String?
no setter
isFavoriteMark num?
getter/setter pair
isSelected bool
getter/setter pair
no setter
masterUserId String?
no setter
name String?
no setter
profileImage String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userName String?
no setter

Methods

copyWith({String? masterUserId, String? groupId, String? name, String? userName, String? email, String? contactNo, String? birthdate, String? accountName, String? isActive, num? isFavoriteMark, String? profileImage, bool isSelected = false, String? createdAt, List<Categories>? categories, List<BannerData>? bannerData}) DeveloperList
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited