FeedMergeDataItem class

Constructors

FeedMergeDataItem({String? postType, String? feedId, String? title, String? description, FeedDate? feedDate, FeedMedia? feedMedia, String? createdAtTimestamp, String? createdAt, String? createdTime, String? location, String? subTitle, CampaignDate? campaignDate, String? campaignShareUrl, String? campaignId, CampaignMedia? campaignMedia})
FeedMergeDataItem.fromJson(dynamic json)

Properties

campaignDate CampaignDate?
no setter
campaignId String?
no setter
campaignMedia CampaignMedia?
no setter
campaignShareUrl String?
no setter
createdAt String?
no setter
createdAtTimestamp String?
no setter
createdTime String?
no setter
description String?
no setter
feedDate FeedDate?
no setter
feedId String?
no setter
feedMedia FeedMedia?
no setter
hashCode int
The hash code for this object.
no setterinherited
location String?
no setter
postType String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subTitle String?
no setter
title String?
no setter

Methods

copyWith({String? postType, String? feedId, String? title, String? description, FeedDate? feedDate, FeedMedia? feedMedia, String? createdAtTimestamp, String? createdAt, String? createdTime, String? location, String? subTitle, CampaignDate? campaignDate, String? campaignShareUrl, String? campaignId, CampaignMedia? campaignMedia}) FeedMergeDataItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited