FloorData class
Constructors
Properties
- category → String?
-
no setter
- flatType → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
no setter
- isSelected ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unitData
→ List<
UnitData> ? -
no setter
- unitFloor → String?
-
no setter
- unitFloorTemp → String?
-
no setter
Methods
-
copyWith(
{String? id, String? flatType, String? category, String? unitFloor, String? unitFloorTemp, bool isSelected = false, List< UnitData> ? unitData}) → FloorData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited