UnitData class

Constructors

UnitData({String? id, String? flatNoTemp, String? superBuiltUpArea, String? superBuiltUpAreaTemp})
UnitData.fromJson(dynamic json)

Properties

flatNoTemp String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
superBuiltUpArea String?
no setter
superBuiltUpAreaTemp String?
no setter

Methods

copyWith({String? id, String? flatNoTemp, String? superBuiltUpArea, String? superBuiltUpAreaTemp}) UnitData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited