Data class
Constructors
Properties
- adminModuleId → String?
-
no setter
- adminSlug → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
no setter
- inquiryType → String?
-
no setter
- pageName → String?
-
no setter
- pageType → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String?
-
no setter
Methods
-
copyWith(
{String? id, String? inquiryType, String? pageType, String? adminSlug, String? adminModuleId, String? slug, String? pageName}) → Data -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited