InquiryProjectData class
Constructors
-
InquiryProjectData({num? projectId, String? projectIdString, num? otherProjectId, String? projectTitle, String? projectName, String? projectSlug, String? masterUserId, bool? isSelected, List<
InquiryTypes> ? inquiryTypes, String? category}) - InquiryProjectData.fromJson(dynamic json)
Properties
- category → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inquiryTypes
→ List<
InquiryTypes> ? -
no setter
- isSelected → bool?
-
no setter
- masterUserId → String?
-
no setter
- otherProjectId → num?
-
no setter
- projectId → num?
-
no setter
- projectIdString → String?
-
no setter
- projectName → String?
-
no setter
- projectSlug → String?
-
no setter
- projectTitle → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected ← bool
-
no getter
Methods
-
copyWith(
{num? projectId, String? projectIdString, num? otherProjectId, String? projectTitle, String? projectName, String? projectSlug, String? masterUserId, bool? isSelected, List< InquiryTypes> ? inquiryTypes, String? category}) → InquiryProjectData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited