InquiryTypes class
Constructors
- InquiryTypes({String? type, bool? isSelected})
- InquiryTypes.fromJson(dynamic json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSelected → bool?
-
no setter
- isSelectedValue ← bool
-
no getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
no setter
Methods
-
copyWith(
{String? type, bool? isSelected}) → InquiryTypes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited