MyTeamTargetResponse class

Constructors

MyTeamTargetResponse({QuarterDetails? quarterDetails, List<TeamsTarget>? teamsTarget, List<TeamsTarget>? cpUsers, String? yourTarget, String? teamTotalTragets, String? totalTarget, num? success, String? message})
MyTeamTargetResponse.fromJson(dynamic json)

Properties

cpUsers List<TeamsTarget>?
no setter
hashCode int
The hash code for this object.
no setterinherited
message String?
no setter
quarterDetails QuarterDetails?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success num?
no setter
teamsTarget List<TeamsTarget>?
no setter
teamTotalTragets String?
no setter
totalTarget String?
no setter
yourTarget String?
no setter

Methods

copyWith({QuarterDetails? quarterDetails, List<TeamsTarget>? teamsTarget, List<TeamsTarget>? cpUsers, String? yourTarget, String? teamTotalTragets, String? totalTarget, num? success, String? message}) MyTeamTargetResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited