UserData class

Constructors

UserData({String? userId, String? cpCode, String? firstName, String? lastName, String? companyName, String? contactNo, String? emailAddress, String? profileImage, String? birthdate, String? birthdateTime, String? address, String? registerText, String? reraNo, String? gender, String? residentialStatus, String? maritalStatus})
UserData.fromJson(dynamic json)

Properties

address String?
no setter
birthdate String?
no setter
birthdateTime String?
no setter
companyName String?
no setter
contactNo String?
no setter
cpCode String?
no setter
emailAddress String?
no setter
firstName String?
no setter
gender String?
no setter
hashCode int
The hash code for this object.
no setterinherited
lastName String?
no setter
maritalStatus String?
no setter
profileImage String?
no setter
registerText String?
no setter
reraNo String?
no setter
residentialStatus String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
no setter

Methods

copyWith({String? userId, String? cpCode, String? firstName, String? lastName, String? companyName, String? contactNo, String? emailAddress, String? profileImage, String? birthdate, String? birthdateTime, String? address, String? registerText, String? reraNo, String? gender, String? residentialStatus, String? maritalStatus}) UserData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited