ProjectData class
Constructors
- ProjectData({String? projectId, String? slug, String? projectName, String? projectTitle, String? projectTitleSmall, String? total, bool isSelected = false, String? category})
- ProjectData.fromJson(dynamic json)
Properties
- category → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSelected ↔ bool
-
getter/setter pair
- projectId → String?
-
no setter
- projectName → String?
-
no setter
- projectTitle → String?
-
no setter
- projectTitleSmall → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String?
-
no setter
- total → String?
-
no setter
Methods
-
copyWith(
{String? projectId, String? slug, String? projectName, String? projectTitle, String? projectTitleSmall, String? total, bool isSelected = false, String? category}) → ProjectData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited