Data class

Constructors

Data({String? title, String? description, String? createdAt, String? createdTime, String? updatedAt, String? updatedTime, String? isActive, String? masterUserId, List<VideosLink>? videosLink, List<Files>? files, bool? isSelected})
Data.fromJson(dynamic json)

Properties

createdAt String?
no setter
createdTime String?
no setter
description String?
no setter
files List<Files>?
no setter
hashCode int
The hash code for this object.
no setterinherited
isActive String?
no setter
isSelected bool?
getter/setter pair
masterUserId String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
no setter
updatedAt String?
no setter
updatedTime String?
no setter
no setter

Methods

copyWith({String? title, String? description, String? createdAt, String? createdTime, String? updatedAt, String? updatedTime, String? isActive, String? masterUserId, List<VideosLink>? videosLink, List<Files>? files}) Data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited