InquiryUpdate class

Mixed-in types

Constructors

InquiryUpdate()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
inquirySuccess String
no setter
isBottomHide int
no setter
isProfileUpdate int
no setter
jsonBody Map<String, String>
no setter
jsonBodyForCP Map<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedLocation String
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setCPJsonData(Map<String, String> jsonBody) → void
setInquirySuccess(String data) → void
setIsBottomHide(int isBottomHide) → void
setIsProfileUpdate(int profileUpdate) → void
setJsonData(Map<String, String> jsonBody) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateLocation(String value) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited