Indicator class
Mediates indicator building and animation.
Constructors
- Indicator({required AnimationController normalController, required AnimationController highlightedController, int index = 0})
-
normalControllerAnimation controller when state changes to normalhighlightedControllerAnimation controller when state changes to selectedwidgetIndicator widgetbuilderWidgetbuilder objectindexDetermine index on the stack
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightedController → AnimationController
-
final
- index → int
-
final
- normalController → AnimationController
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited